CHANGES
=======

0.1.0 (2015-05-22)
------------------

Initial release.

* Support integer series validator
* Support float series validator
* Support dataframe validator

* Testing on python2.7 and python 3.4

0.0.0 (2015-05-17)
------------------

Create this project.

